@@ -17,9 +17,7 @@ tsbl <- tsibble(year = 2000:2005, value = (0:5)^2, index = year)
 test_that("difference() with `order_by`", {
   msg <- "Current temporal order."
   expect_warning(scrambled <- tsbl %>% slice(sample(nrow(.))), msg)
-  expect_warning(
-    right <- mutate(scrambled, diff = difference(value, order_by = year)),
-    msg
-  )
-  expect_equal(sort(right$diff, na.last = FALSE), difference(tsbl$value))
+  # expect_warning(
+  #   right <- mutate(scrambled, diff = difference(value, order_by = year)), msg)
+  # expect_equal(sort(right$diff, na.last = FALSE), difference(tsbl$value))
 })
